pub enum ConfigDocument {
Json(Value),
Yaml(Value),
Toml(Value),
Properties(PropertiesDocument),
Text(String),
Binary(Vec<u8>),
}Expand description
Parsed configuration content returned by the library.
Variants
Json(Value)
Parsed JSON payload.
Yaml(Value)
Parsed YAML payload converted into a JSON-like value.
Toml(Value)
Parsed TOML payload converted into a JSON-like value.
Properties(PropertiesDocument)
Parsed Java properties payload.
Text(String)
UTF-8 text with no built-in structure.
Binary(Vec<u8>)
Raw binary content.
Implementations
Sourceimpl ConfigDocument
impl ConfigDocument
Sourcepub fn format(&self) -> DocumentFormat
pub fn format(&self) -> DocumentFormat
Returns the document format.
Sourcepub fn to_value(&self) -> Result<Value>
pub fn to_value(&self) -> Result<Value>
Converts the document into a JSON-like nested value without scalar coercion.
Sourcepub fn to_value_with_coercion(&self, coercion: ScalarCoercion) -> Result<Value>
pub fn to_value_with_coercion(&self, coercion: ScalarCoercion) -> Result<Value>
Converts the document into a JSON-like nested value.
Sourcepub fn deserialize<T>(&self) -> Result<T>where
T: DeserializeOwned,
pub fn deserialize<T>(&self) -> Result<T>where
T: DeserializeOwned,
Deserializes the document into a Rust type using smart scalar coercion.
Sourcepub fn deserialize_with_coercion<T>(
&self,
coercion: ScalarCoercion,
) -> Result<T>where
T: DeserializeOwned,
pub fn deserialize_with_coercion<T>(
&self,
coercion: ScalarCoercion,
) -> Result<T>where
T: DeserializeOwned,
Deserializes the document into a Rust type using the requested coercion mode.
Sourcepub fn deserialize_strict<T>(&self) -> Result<T>where
T: DeserializeOwned,
pub fn deserialize_strict<T>(&self) -> Result<T>where
T: DeserializeOwned,
Deserializes the document without scalar coercion.