pub struct ConfigResource { /* private fields */ }Expand description
Raw resource content fetched from the plain-text Spring Config endpoint.
Implementations
Sourceimpl ConfigResource
impl ConfigResource
Sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
Returns the response content type, when present.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consumes the resource and returns the raw bytes.
Sourcepub fn format(&self) -> DocumentFormat
pub fn format(&self) -> DocumentFormat
Guesses the document format from the resource path, content type, and payload.
Sourcepub fn parse(&self) -> Result<ConfigDocument>
pub fn parse(&self) -> Result<ConfigDocument>
Parses the resource into a ConfigDocument.
Sourcepub fn deserialize<T>(&self) -> Result<T>where
T: DeserializeOwned,
pub fn deserialize<T>(&self) -> Result<T>where
T: DeserializeOwned,
Parses and deserializes the resource into a Rust type.