pub struct EnvironmentRequest { /* private fields */ }Expand description
A request for the Spring Environment endpoint.
Implementations
Sourceimpl EnvironmentRequest
impl EnvironmentRequest
Sourcepub fn new<A, I, P>(application: A, profiles: I) -> Result<Self>
pub fn new<A, I, P>(application: A, profiles: I) -> Result<Self>
Creates a new environment request.
Sourcepub fn label(self, label: impl Into<String>) -> Self
pub fn label(self, label: impl Into<String>) -> Self
Overrides the git label, branch, tag, or commit for this request.
Sourcepub fn resolve_placeholders(self, enabled: bool) -> Self
pub fn resolve_placeholders(self, enabled: bool) -> Self
Controls the resolvePlaceholders query parameter used by YAML and properties endpoints.
Sourcepub fn application(&self) -> &str
pub fn application(&self) -> &str
Returns the application name.
Sourcepub fn resolve_placeholders_enabled(&self) -> bool
pub fn resolve_placeholders_enabled(&self) -> bool
Returns whether placeholder resolution should be requested for alternative formats.