Error

Enum Error 

pub enum Error {
Show 19 variants InvalidBaseUrl(String), InvalidBaseUrlShape(String), EmptyApplication, EmptyProfiles, EmptyResourcePath, MissingEnvironmentVariable { name: &'static str, }, InvalidEnvironmentVariable { name: &'static str, reason: &'static str, value: String, }, InvalidBootstrapConfiguration(String), InvalidHeaderName(String), InvalidHeaderValue { name: String, value: String, }, Transport { url: String, source: Error, }, HttpStatus { status: StatusCode, url: String, body: String, }, Json { url: String, source: Error, }, Yaml { url: String, source: Error, }, Toml { url: String, source: Error, }, Properties { origin: String, reason: String, }, Utf8 { url: String, source: FromUtf8Error, }, UnsupportedBindingFormat { format: &'static str, }, Bind { origin: String, source: Error, },
}
Error type returned by the Spring Cloud Config client.

Variants



InvalidBaseUrl(String)

The base URL could not be parsed.



InvalidBaseUrlShape(String)

The base URL contains a query string or fragment, which is not supported.



EmptyApplication

The application name is empty.



EmptyProfiles

No profiles were supplied.



EmptyResourcePath

The resource path is empty.



MissingEnvironmentVariable

A required environment variable is missing.

Fields

name: &'static str

The environment variable name.



InvalidEnvironmentVariable

An environment variable has an invalid value.

Fields

name: &'static str

The environment variable name.

reason: &'static str

A short reason.

value: String

The provided value.



InvalidBootstrapConfiguration(String)

The bootstrap configuration is internally inconsistent.



InvalidHeaderName(String)

A custom HTTP header name is invalid.



InvalidHeaderValue

A custom HTTP header value is invalid.

Fields

name: String

The header name.

value: String

The header value.



Transport

The HTTP request failed before a valid response was received.

Fields

url: String

The target URL.

source: Error

The transport error.



HttpStatus

The Config Server returned a non-success HTTP status.

Fields

status: StatusCode

The HTTP status code.

url: String

The target URL.

body: String

The response body, when available.



Json

The response body could not be parsed as JSON.

Fields

url: String

The target URL.

source: Error

The parse error.



Yaml

The response body could not be parsed as YAML.

Fields

url: String

The target URL.

source: Error

The parse error.



Toml

The response body could not be parsed as TOML.

Fields

url: String

The target URL.

source: Error

The parse error.



Properties

The response body could not be parsed as Java properties.

Fields

origin: String

The origin being parsed.

reason: String

A human-readable reason.



Utf8

The response body was expected to be UTF-8 text but was not valid UTF-8.

Fields

url: String

The target URL.

source: FromUtf8Error

The UTF-8 decode error.



UnsupportedBindingFormat

Typed deserialization is not supported for the requested document kind.

Fields

format: &'static str

The format name.



Bind

The configuration payload could not be bound into the requested Rust type.

Fields

origin: String

A short description of the binding source.

source: Error

The Serde error.